
// #name = Tribes 2 Team Tracker
// #version = 1.00
// #date = June 14, 2002
// #author =Mark Dickenson ([AKA]PanamaJack)
// #email = akapanamajack@wildmail.com
// #web = http://www.planetstarsiege.com/pj
// #description = Support routines for my scripts
// #acknowledgements = none
// #status = working

//
//	Function Calls
//
//	If %detag is left off the following function calls
//	will not strip the tag information from the value passed.
//
//	If you would like the functions to automatically strip the tag set %detag to 1.
//
//	getClientName(%clientId, %detag) - Returns the Clients player name
//	getClientTag(%clientId, %detag) - Returns the Player Tag for use with %playertag.score, %playertag.getInventory(), ect
//	getClientId(%realname, %detag) - Returns the Client ID for that player name
//	getClientTeamId(%clientId, %detag) - Returns the Team ID for that client (usually 1 or 2)
//	getClientTeamName(%clientId, %detag) - Returns the Team Name for that client
//
//	getManagerId() - Returns your Client ID
//	getManagerName() - returns your Client Name
//	getManagerTribe() - Returns your Client Tribe ID if any
//	getManagerVehicle() - Returns vehicle type client is in - None, Hoverbike, Assault, MPB, Bomber, Shrike, HAPC
//	getManagerPosition() = Returns location in vehicle - None, Pilot, Bombardier, Tailgunner, Gunner, LeftRear, LeftFront, RightRear, RightFront
//
//	getEnemyTeam() - returns Enemy Team Name
//	getFriendlyTeam() - returns Friendly Team Name
//

//
//	isManagerName(%clientname, %detag) - Compares the client name with the Managers Name
//							No Match reurns false
//							Match returns true
//
//	isManagerName should be used for ALL checks of player names when you are trying to find a match to
//	the clients player name.

//
//	New Callback Triggers
//	All Callback triggers pass Detagged Information
//
//	'msgITeamChanged' - Is triggered when you change teams and passes your Client ID
//	'msgFriendlyJoined' - Is triggered when a new client joins your team and passes the players Client ID
//	'msgEnemyJoined' - Is triggered when a new client joins the enemy team and passes the players Client ID
//	'msgLeftTeam' - Is triggered when a client leaves your team and passes the players Client ID
//	'msgTeamCountUpdate' - Is triggered when player totals change and passes Team 1's Total and Team 2's Total
//
//	example:
//
//	addMessageCallback('msgFriendlyJoined', handleMyJoined);
//
//	function handleMyJoined(%msgType, %msgString, %clientId) {
//	}
//
//	%msgType = msgFriendlyJoined
//	%msgString = ""
//	%clientId = passed detagged client ID argument
//
//	example:
//
//	addMessageCallback('msgTeamCountUpdate', handleMyTeamCount);
//
//	function handleMyJoined(%msgType, %msgString, %team1total, %team2total, %observertotal) {
//	}
//
//	%msgType = msgFriendlyJoined
//	%msgString = ""
//	%team1total = passed total players on team 1
//	%team2total = passed total players on team 2
//	%observertotal = passed total number of observers
//

new ScriptObject(PJTeamData){};


addMessageCallback('MsgClientJoin', handleTTjoin);
addMessageCallback('MsgClientJoinTeam', handleTTjointeam);
addMessageCallback('MsgClientDrop', handleTTdrop);
addMessageCallBack('MsgClientReady', playguionWakeTrack);

function playguionWakeTrack(%msgType, %msgString, %gameType){

	if(%gameType $= "TR2Game")
		schedule(3000, 0, PJRebuildTeamList);
}

function getManagerPosition() {

	return $PJVehiclePosition;
}

function getManagerVehicle() {

	return $PJVehicleType;
}

function isManagerName(%clientname, %detag) {

	if(%detag == 1)
		%clientname = detag(%clientname);

	if(%clientname $= getManagerName()) {
		return true;
	} else {
		return false;
	}
}

function getManagerId() {

	return $CurrentClientId;
}

function getManagerName() {

	return $CurrentPlayerName;
}

function getManagerTribe() {

	return $CurrentPlayerTag;
}

function getEnemyTeam() {

	return $CurrentTeamEnemy;
}

function getFriendlyTeam() {

	return $CurrentTeamFriendly;
}

function getClientTag(%clientId, %detag) {

	if(%detag == 1)
		%clientId = detag(%clientId);

	return $PlayerList[%clientId];
}

function getClientName(%clientId, %detag) {

	if(%detag == 1)
		%clientId = detag(%clientId);

	%player = $PlayerList[%clientId];

	return %player.name;
}

function getClientId(%realname, %detag) {

	if(%detag == 1)
		%realname = detag(%realname);

	if(PJTeamData.name2id[%realname] $= "") {
		return false;
	} else {
		return PJTeamData.name2id[%realname];
	}
}

function getClientTeamId(%clientId, %detag) {

	if(%detag == 1)
		%clientId = detag(%clientId);

	%player = $PlayerList[%clientId];

	return %player.teamId;
}

function getClientTeamName(%clientId, %detag) {

	if(%detag == 1)
		%clientId = detag(%clientId);

	%player = $PlayerList[%clientId];
	%teamId = %player.teamId;

	return $clTeamScore[%teamId,0];
}

function handleTTjoin(%msgType, %msgString, %clientName, %clientId, %targetId, %isAI, %isAdmin, %isSuperAdmin, %isSmurf, %guid) {

	if(StrStr(%msgString, "Welcome to Tribes") != -1) {
		echo("I found your Client Number: "@%clientId);
		$CurrentClientId = %clientId;
		$CurrentPlayerName = detag(%clientName);

		if(%isSmurf) {
			echo("Oh How Smurfy you are...");
			$CurrentPlayerTag = "";
		}
	}
}

function handleTTjointeam(%msgType, %msgString, %clientName, %teamName, %clientId, %teamId) {

	%realname = detag(%clientName);
	%realteam = detag(%teamName);

	if(%clientId == getManagerId()) {
		if(%teamId == 0) {
			$CurrentTeamFriendly = "Unassigned";
			$CurrentTeamEnemy = "Unassigned";
		} else {
			$CurrentTeamFriendly = $clTeamScore[%teamId, 0];
			FindEnemyTeam();
		}
		if($PJGameType $= "TR2Game")
			schedule(3000, 0, PJRebuildTeamList);
	}

	if($PJTeamTotals < %teamId)
		$PJTeamTotals = %teamId;

	if(%realname $= "")
		%realname = getClientName(%clientid);

	%oldteam = getClientTeamId(%clientId);

	for(%i = 0; %i <= $clTeamCount; %i++) {
		if(%i != %oldteam)
			PJTeam::DeleteFromTeam(%clientid, %i);
	}

	PJTeam::Joined(%clientid, %realname, %teamid, %realteam);
//	error(%clientid, %realname, %teamid, %realteam);

}

function handleTTdrop(%msgType, %msgString, %clientName, %clientId) {

	%realname = detag(%clientName);
	PJTeamData.name2id[%realname] = "";

	PJTeam::List();

	for(%i = 0; %i <= $clTeamCount; %i++) {
		PJTeam::DeleteFromTeam(%clientid, %i);
	}
}

function FindEnemyTeam() {

	for(%i = 1; %i <= $clTeamCount; %i++) {
		if ($clTeamScore[%i, 0] !$= $CurrentTeamFriendly)
			$CurrentTeamEnemy = $clTeamScore[%i, 0];
	}
}

function PJTeam::Reset() {

     if(isObject(PJTeamData))
          PJTeamData.delete();

     new ScriptObject(PJTeamData){};

//	deletevariables("$PJTeamData::name2id*");
	$CurrentTeamFriendly = "";
	$CurrentTeamEnemy = "";
	$CurrentClientId = 0;
}


function PJTeam::Joined(%clientid, %realname, %teamid, %realteam) {

	PJTeamData.name2id[%realname] = %clientid;

	if(isManagerName(%realname)) {
		clientCmdServerMessage('msgITeamChanged', "", %clientId);
	}

	PJTeam::List();
	PJTeam::AddToTeam(%clientid, %teamid);
}



function PJTeam::AddToTeam(%client, %team) {

	if(%client == $CurrentClientId) {
		for(%i = 0; %i < PlayerListGroup.getCount(); %i++) {
			%player = PlayerListGroup.getObject(%i);
			if(%player.teamId == %team) {
				clientCmdServerMessage('msgFriendlyJoined', "", %player.clientId);
			}
		}
	} else if(%team == getClientTeamId(getManagerId())) {
		clientCmdServerMessage('msgFriendlyJoined', "", %client);
		} else clientCmdServerMessage('msgEnemyJoined', "", %client);
}

function PJTeam::DeleteFromTeam(%client, %team) {

	if(%client == $CurrentClientId) {
		for(%i = 0; %i < PlayerListGroup.getCount(); %i++) {
			%player = PlayerListGroup.getObject(%i);
			if(%player.teamId == %team)
				clientCmdServerMessage('msgFriendlyDropped', "", %player.clientId);
		}
	} else clientCmdServerMessage('msgLeftTeam', "", %client);
}


function PJTeam::List(%show) {

	if($PJTeamTotals < 2)
		$PJTeamTotals = 2;

	for(%tt = 0; %tt <= $PJTeamTotals; %tt++) {
	$PJteam::Totals[%tt] = 0;

		for(%i = 0; %i < PlayerListGroup.getCount(); %i++) {
			%player = PlayerListGroup.getObject(%i);
			if(%player.teamId == %tt) {
				if(%show !$= "")
					echo($PJteam::Totals[%tt]@". Name = "@%player.name@", ID = "@%player.clientId@", Team = "@%player.teamId@", Teamname = "@$clTeamScore[%player.teamId,0]);
				$PJteam::Totals[%tt]++;
			}
		}

		if(%show !$= "")
			echo("\nTeam " @ %tt @ " Total = "@$PJteam::Totals[%tt] @ "\n\n");
	}

	clientCmdServerMessage('msgTeamCountUpdate', "", $PJteam::Totals[1], $PJteam::Totals[2], $PJTeam::Totals[0]);
}

function PJRebuildTeamList() {

	if($PJTeamTotals < 2)
		$PJTeamTotals = 2;

	for(%tt = 0; %tt <= $PJTeamTotals; %tt++) {
		for(%i = 0; %i < PlayerListGroup.getCount(); %i++) {
			%player = PlayerListGroup.getObject(%i);
			if(%player.teamId == %tt) {
				handleTTjointeam("", "", %player.name, $clTeamScore[%player.teamId,0], %player.clientId, %player.teamId);
			}
		}
	}
}


$CurrentPlayerName = "";
$CurrentPlayerTag = "";
$CurrentTeamFriendly = "";
$CurrentTeamEnemy = "";
$CurrentClientId = 0;
$PJScript::Support1 = 1;

PJTeam::Reset();
